@@ -6,25 +6,15 @@
  * Date        : 2007-09-22
  * Description : Core database field enumerations.
  *
- * Copyright (C) 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2013      by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CORE_DB_FIELDS_H
-#define DIGIKAM_CORE_DB_FIELDS_H
+#pragma once
 
 #include "digikam_config.h"
 
@@ -80,17 +70,17 @@ typedef uint8_t ImagesMinSizeType;
 enum ItemInformationField
 {
     ItemInformationNone  = 0,
-    Rating                = 1 << 0,
-    CreationDate          = 1 << 1,
-    DigitizationDate      = 1 << 2,
-    Orientation           = 1 << 3,
-    Width                 = 1 << 4,
-    Height                = 1 << 5,
-    Format                = 1 << 6,
-    ColorDepth            = 1 << 7,
-    ColorModel            = 1 << 8,
-    ColorLabel            = 1 << 9,
-    PickLabel             = 1 << 10,
+    Rating               = 1 << 0,
+    CreationDate         = 1 << 1,
+    DigitizationDate     = 1 << 2,
+    Orientation          = 1 << 3,
+    Width                = 1 << 4,
+    Height               = 1 << 5,
+    Format               = 1 << 6,
+    ColorDepth           = 1 << 7,
+    ColorModel           = 1 << 8,
+    ColorLabel           = 1 << 9,
+    PickLabel            = 1 << 10,
     ItemInformationAll   = Rating           |
                            CreationDate     |
                            DigitizationDate |
@@ -276,14 +266,11 @@ template<typename FieldName> class DatabaseFieldsEnumIterator
 
 public:
 
-    DatabaseFieldsEnumIterator()
-      : i(FieldMetaInfo<FieldName>::First)
-    {
-    }
+    DatabaseFieldsEnumIterator() = default;
 
     bool atEnd() const
     {
-        return i > FieldMetaInfo<FieldName>::Last;
+        return (i > FieldMetaInfo<FieldName>::Last);
     }
 
     void operator++()
@@ -298,7 +285,7 @@ public:
 
 private:
 
-    int i;
+    int i = FieldMetaInfo<FieldName>::First;
 };
 
 /**
@@ -538,42 +525,42 @@ public:
     // So we can store up to 64 enums, with 26 flags each.
     static inline unsigned int uniqueKey(Images f)
     {
-        return (int)f | (0 << 26);
+        return (unsigned int)f;
     }
 
     static inline unsigned int uniqueKey(ItemInformation f)
     {
-        return (int)f | (1 << 26);
+        return (unsigned int)f | (unsigned int)(1 << 26);
     }
 
     static inline unsigned int uniqueKey(ImageMetadata f)
     {
-        return (int)f | (2 << 26);
+        return (unsigned int)f | (unsigned int)(2 << 26);
     }
 
     static inline unsigned int uniqueKey(ItemComments f)
     {
-        return (int)f | (3 << 26);
+        return (unsigned int)f | (unsigned int)(3 << 26);
     }
 
     static inline unsigned int uniqueKey(ItemPositions f)
     {
-        return (int)f | (4 << 26);
+        return (unsigned int)f | (unsigned int)(4 << 26);
     }
 
     static inline unsigned int uniqueKey(ImageHistoryInfo f)
     {
-        return (int)f | (5 << 26);
+        return (unsigned int)f | (unsigned int)(5 << 26);
     }
 
     static inline unsigned int uniqueKey(VideoMetadata f)
     {
-        return (int)f | (6 << 26);
+        return (unsigned int)f | (unsigned int)(6 << 26);
     }
 
     static inline unsigned int uniqueKey(CustomEnum f)
     {
-        return      f | (63 << 26);
+        return (unsigned int)f | ((unsigned int)(63) << 26);
     }
 
     // override relevant methods from QHash
@@ -599,5 +586,3 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::VideoMetadata)
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::ItemComments)
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::ItemPositions)
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::DatabaseFields::ImageHistoryInfo)
-
-#endif // DIGIKAM_CORE_DB_FIELDS_H
