@@ -6,24 +6,14 @@
  * Date        : 2004-12-01
  * Description : image curves manipulation methods.
  *
- * Copyright (C) 2004-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CURVES_CONTAINER_H
-#define DIGIKAM_CURVES_CONTAINER_H
+#pragma once
 
 // Qt includes
 
@@ -34,6 +24,7 @@
 
 #include "digikam_globals.h"
 #include "digikam_export.h"
+#include "imagecurves.h"
 
 namespace Digikam
 {
@@ -50,7 +41,7 @@ public:
      * Initially, the values are empty.
      * Call initialize() before adjusting values manually.
      */
-    CurvesContainer();
+    CurvesContainer() = default;
     CurvesContainer(int type, bool sixteenBit);
 
     /**
@@ -83,12 +74,10 @@ public:
      *  Smooth : QPolygon have size of 18 points.
      *  Free   : QPolygon have size of 255 or 65535 values.
      */
-    int                     curvesType;
+    int                     curvesType = ImageCurves::CURVE_SMOOTH;
     QPolygon                values[ColorChannels];
 
-    bool                    sixteenBit;
+    bool                    sixteenBit = false;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_CURVES_CONTAINER_H
