@@ -6,14 +6,13 @@
  * Date        : 2009-08-03
  * Description : digiKam config header
  *
- * SPDX-FileCopyrightText: 2009-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CONFIG_H
-#define DIGIKAM_CONFIG_H
+#pragma once
 
 /* Define to 1 if you have KDEPIM shared library installed */
 /* #undef HAVE_AKONADICONTACT */
@@ -28,10 +27,10 @@
 #define HAVE_SONNET 1
 
 /* Define to 1 if an external Ksane shared library have been found */
-#define HAVE_KSANE 1
+/* #undef HAVE_KSANE */
 
 /* Define to 1 if an external Marble shared library have been found */
-#define HAVE_MARBLE 1
+#define HAVE_GEOLOCATION 1
 
 /* Define to 1 if an external Eigen3 shared library have been found */
 #define HAVE_EIGEN3 1
@@ -43,7 +42,7 @@
 #define HAVE_HEIF 1
 
 /* The Eigen3 version string, if found, or an empty string otherwise */
-#define EIGEN3_VERSION_STRING "3.3.9"
+#define EIGEN3_VERSION_STRING "3.4.0"
 
 /* Define to 1 if GPhoto2 shared library is installed */
 #define HAVE_GPHOTO2 1
@@ -51,6 +50,9 @@
 /* Define to 1 if Jasper shared library is installed */
 #define HAVE_JASPER 1
 
+/* Define to 1 if libjxl shared library is installed */
+#define HAVE_JXL 1
+
 /* Define to 1 if libgphoto2 2.5 shared library is installed */
 #define HAVE_GPHOTO25 1
 
@@ -100,20 +102,12 @@
 /* #undef HAVE_APPSTYLE_SUPPORT */
 
 /* Define to 1 if system use QtMultimedia */
-/* #undef HAVE_QTMULTIMEDIA */
-
-/* Define to 1 if system use QtWebEngine */
-#define HAVE_QWEBENGINE 1
+#define HAVE_QTMULTIMEDIA 1
 
 /* Define to 1 if system use QtXmlPatterns */
-#define HAVE_QTXMLPATTERNS 1
+/* #undef HAVE_QTXMLPATTERNS */
 
 /* Define to 1 if ImageMagick codecs are supported */
 #define HAVE_IMAGE_MAGICK 1
 
-/* Defines to 1 if the Dr. Mingw crash handler should be used */
-/* #undef HAVE_DRMINGW */
-
 #define LIBEXEC_INSTALL_DIR "/usr/local/libexec"
-
-#endif // DIGIKAM_CONFIG_H
