@@ -6,14 +6,13 @@
  * Date        : 2004-09-09
  * Description : digiKam release ID header.
  *
- * SPDX-FileCopyrightText: 2004-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_VERSION_H
-#define DIGIKAM_VERSION_H
+#pragma once
 
 // Qt includes
 
@@ -27,8 +26,8 @@
 namespace Digikam
 {
 
-static const char digikam_version_short[]  = "8.2.0";
-static const char digikam_version[]        = "8.2.0";
+static const char digikam_version_short[]  = "8.4.0";
+static const char digikam_version[]        = "8.4.0";
 static const char digikam_version_suffix[] = "";
 static const char digikam_build_type[]     = "Release";
 
@@ -54,5 +53,3 @@ DIGIKAM_EXPORT const QDateTime digiKamBuildDate();
 DIGIKAM_EXPORT int digiKamMakeIntegerVersion(int major, int minor, int patch);
 
 } // namespace Digikam
-
-#endif // DIGIKAM_VERSION_H
