@@ -6,22 +6,13 @@
  * Date        : 2006-09-13
  * Description : a widget to provide conflict rules to save image.
  *
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_FILE_SAVE_CONFLICT_BOX_H
-#define DIGIKAM_FILE_SAVE_CONFLICT_BOX_H
+#pragma once
 
 // Qt includes
 
@@ -69,9 +60,7 @@ Q_SIGNALS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_FILE_SAVE_CONFLICT_BOX_H
