@@ -6,26 +6,16 @@
  * Date        : 2005-04-21
  * Description : Handling access to one item and associated data
  *
- * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2013      by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_INFO_H
-#define DIGIKAM_ITEM_INFO_H
+#pragma once
 
 // Qt includes
 
@@ -194,6 +184,11 @@ public:
      */
     QString filePath()                                                                  const;
 
+    /**
+     * Returns the relative path part to the image
+     */
+    QString relativePath()                                                              const;
+
     /**
      * @return the unique image id for this item
      */
@@ -490,7 +485,7 @@ public:
      * You need to hold CoreDbAccess to ensure the validity.
      * For simple, cached read access see comment().
      */
-    ItemComments imageComments(CoreDbAccess& access)                                    const;
+    ItemComments imageComments(const CoreDbAccess& access)                                    const;
 
     /**
      * Retrieve the ItemCopyright object for this item.
@@ -678,5 +673,3 @@ DIGIKAM_DATABASE_EXPORT QDebug operator<<(QDebug stream, const ItemInfo& info);
 
 Q_DECLARE_TYPEINFO(Digikam::ItemInfo, Q_MOVABLE_TYPE);
 Q_DECLARE_METATYPE(Digikam::ItemInfo)
-
-#endif // DIGIKAM_ITEM_INFO_H
